@@ -40,9 +40,9 @@ C         RECURSIVELY CALCULATES DISCRETE LEGENDRE POLYNOMIALS, VIA
 C         EQ.(9) OF NEUMAN AND SCHONBACH (1974, INT.J.NUM.METH.ENG.)
 C
       DO 20 J=3,NMOM
-      TEMP=ONE/DFLOAT((J-1)*(N-J+1))
-      COEF(1,J)=DFLOAT(J+J-3)*TEMP
-      COEF(2,J)=DFLOAT((J-2)*(N+J-2))*TEMP
+      TEMP=ONE/DBLE((J-1)*(N-J+1))
+      COEF(1,J)=DBLE(J+J-3)*TEMP
+      COEF(2,J)=DBLE((J-2)*(N+J-2))*TEMP
    20 CONTINUE
       TEMP=-DN-ONE
       CONST=ONE/(DN-ONE)
